package com.steerinfo.dil.mapper;

import com.steerinfo.dil.model.OmstruckOrder;
import com.steerinfo.framework.mapper.IBaseMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Mapper
public interface OmstruckOrderMapper extends IBaseMapper<OmstruckOrder, BigDecimal> {
    //根据销售订单id查找销售订单信息
    List<Map<String, Object>> selectSaleNumberForCarrier(Integer saleOrderId);

    //查询已接收的焦炭发运计划
    List<Map<String, Object>> selectCokeDayPlanAndRecived(Map<String, Object> map);

    //查询已接收的水渣发运计划
    List<Map<String, Object>> selectWaterSlagDayPlanAndRecived(Integer carrierId);

    //查询所有运输订单信息 状态：3
    //查询所有已下发运输订单 状态：4
    List<Map<String, Object>> getAllTruckOrder(Map<String, Object> map);

    //查询最大主键Id
    @Select("select seq_omstruck_order.nextval from dual")
    BigDecimal selectMaxId();

    //通过运输订单Id查询运输订单号
    String getOrderNumberByOrderId(Integer orderId);

    //通过运输订单号查询运输订单ID
    Integer getOrderIdByOrderNumber(String orderNumber);

    //查询所有运力信息
    List<Map<String, Object>> getAllCapacity(Map<String, Object> map);

    //通过运力Id 或 车牌号 修改运输状态
    int updateCapacityByCarIdOrNum(Map<String, Object> map);

    int updateCapacityById(Map<String, Object> map);

    //通过运输订单ID 或 运输订单号 查询运力Id
    BigDecimal getCapacityIdByOrderOrNum(Map<String, Object> map);

    //通过ID获取派单时间
    Date getInsertTimeById(Integer orderId);

    //通过车牌号查询运力id
    BigDecimal getCapacityIdByCapacityNum(String capacityNumber);

    //司机接单调用接口 通过运力Id匹配  /  通过运单ID查询运单信息 APP
    //查询所有接单或拒绝接单的订单 PC -- 采购
    List<Map<String, Object>>   getTruckOrderByCapacityNum(Map<String, Object> map);

    //查询所有接单或拒绝接单的订单 PC -- 销售
    List<Map<String, Object>> getSaleTruckOrderByCapacityNum(Map<String, Object> map);

    //查询司机所有已拒绝过的订单
    List<Map<String, Object>> getReceiveRefuseOrderByCapacityId(Map<String, Object> map);

    //  通过运输订单号或运输订单ID查询总实绩ID和订单类型
    Map<String, Object> getResultTotalIdByOrderNumAndId(Map<String, Object> map);

    // 通过运输订单Id查询运输订单子表有几种物资 ：物资ID
    List<Integer> getMaterialIdListByOrderId(Integer orderId);

    // 查询实绩地点和时间
    List<Map<String, Object>> selectPlaceAndTime(BigDecimal orderId);

    //通过运单号查询运单信息
    List<Map<String, Object>> getOrderByOrderId(BigDecimal orderId);

    //通过运输订单号查询预设路径的作业点ID  及 总实绩ID
    Map<String, Object> getPointIdByOrderNum(Map<String, Object> map);

    //运输派单
    List<Map<String, Object>> getTransportDispatch(Map<String, Object> map);

    //查询已下发未接受的销售订单信息
    List<Map<String, Object>> getOrderUnReceive(BigDecimal orderType);

    //查询已下发已接受的销售订单信息
    List<Map<String, Object>> getOrderReceived(BigDecimal orderType);

    //通过销售订单物资ID查找物资理重和物资件数
    Map<String, Object> selectTheoreticalWeightAndMaterialNumber(Integer saleOrderMaterialId);

    //销售物流：展示已经形成订单的水渣发运计划
    List<Map<String, Object>> selectWaterSlagForOrder(Map<String, Object> map);

    //销售物流：展示已经形成订单的焦炭发运计划
    List<Map<String, Object>> selectCokeRailPlanForOrder(Map<String, Object> map);

    //通过车序号表id查找物资id
    List<Map<String, Object>> selectMaterialIdBysaleOrderMaterialId(Integer saleOrderMaterialId);

    //查找司机排班表信息
    List<Map<String, Object>> selectCapacityAndDriver(Map<String, Object> map);

    //通过用户id查找用户姓名
    String selectPersonNameByPersonnelId(Integer personnelId);

    //通过车牌号、承运商匹配最新的运力id
    BigDecimal selectCapacityId(BigDecimal carrierId, String capacityNumber);

    //通过运输订单ID查询数据 用于websocket推送数据
    Map<String, Object> pushMesToWebsocket(Map<String, Object> map);

    //通过物资id查询批次表匹配最新的批次，关联最新的采购订单号
    Map<String, Object> selectNewOrderId(Map<String, Object> map);

    //查询所有的收货单位
    List<Map<String, Object>> getReceivingUnit();

    //查询所有的发货单位
    List<Map<String, Object>> getSupplier();

    //通过采购订单号查找采购订单ID
    BigDecimal getPurchaseOrderIdByNo(String purchaseOrderNo);


    //App
    //查询主干信息
    Map<String, Object> getSaleTruckOrderByCapacityId(Map<String, Object> map);

    //查询物资信息
    List<Map<String, Object>> getSaleTruckOrderByCapacityNumMaterial(Map<String, Object> map);

    //根据发运计划id查找物资id
    Map<String, Object> selectMaterialIdAndWeightByDayPlanId(Integer dayPlanId);

    //销售模块，查看所有订单
    List<Map<String, Object>> selectAllOrderForSale(Map<String, Object> map);

    //根据车序号id查找销售订单
    List<Map<String, Object>> selectSaleBySaleOrderMaterialId(Integer saleOrderMaterialId);


    //销售：接收运输订单展示pc端界面
    List<Map<String, Object>> selectTransportOrderForSale(Map<String, Object> map);

    //销售：根据承运商查找承运商
    List<Map<String, Object>> selectSaleMaterialIdByCarrierId(Integer carrierId);

    //根据承运商查找销售订单
    List<Map<String, Object>> selectSteelSaleForCarrier(Map<String, Object> map);

    //根据销售订单id查找信息
    List<Map<String, Object>> selectInfoBySaleOrderId(Integer saleOrderId);

    //根据承运商查找发运计划
    List<Map<String, Object>> selectCokeRailPlan(Map<String, Object> map);

    //根据发运计划查找信息
    List<Map<String, Object>> selectInfoByDayPlanId(Map<String, Object> map);

    // 车牌号下拉
    List<Map<String, Object>> getDriverCapacity();

    // 派单信息
    Map<String, Object> getTruckNoDispatchMap(BigDecimal dispatchId);

    // 物资信息
    List<Map<String, Object>> getMaterialMessages(BigDecimal dispatchId);

    // 得到销售订单与物资中间表id
    BigDecimal getSaleMaterialId(BigDecimal dispatchId);

    // 根据车牌号查询运力id
    BigDecimal getCapacityId(String capacityNumber);

    // 根据运力id查询司机排班id
    BigDecimal getDriverCapacityId(BigDecimal capacityId);

    List<Map<String,Object>> getCapacityAndDriver(Map<String,Object> mapValue);

    List<BigDecimal> getNullOrNotNull(BigDecimal dispatchId);

    BigDecimal getInwardMaterial(BigDecimal planId);

    List<Map<String, Object>> getInwardOrderList(Map<String, Object> mapValue);

    List<Map<String, Object>> getResultList(BigDecimal driverCapacityId);

    Map<String, Object> sendOrderToApp(Map<String, Object> map);

    Map<String, Object> getSaleOrderMap(BigDecimal orderId);

    Map<String, Object> getSteelInwardOrderMap(BigDecimal orderId);

    Map<String, Object> getPurchaseOrderMap(BigDecimal orderId);

    Map<String, Object> getInwardOrderMap(BigDecimal orderId);

    //通过订单Id查询该订单下所有的物资
    List<Map<String,Object>> getMaterialMes(BigDecimal orderId);

    //根据运输订单查询车牌号
    String selectCapacityNumber(BigDecimal orderId);

    //根据运输订单查询运输状态
    BigDecimal selectOrderType(BigDecimal orderId);

    BigDecimal selectOrderId(BigDecimal dcId);

    //查询采购订单数据 给司机
    Map<String, Object> getCGOrderMessageToApp(@Param("orderId") BigDecimal orderId);

    //查询内转运输订单给APP 9 10 11
    Map<String, Object> getNZOrderMessageToApp(@Param("orderId") BigDecimal orderId);

    //查询采购零星物资订单给app 12
    Map<String,Object>  getSporadicOrder(@Param("orderId") BigDecimal orderId);

    //查询采购零星物资出厂订单给app 13
    Map<String,Object> getLxOutFactoryOrder(@Param("orderId") BigDecimal orderId);

    //查询发运计划运输订单给APP  2 3 4
    Map<String, Object> getFYJHOrderMessageToApp(@Param("orderId") BigDecimal orderId);

    //查询销售运输订单给APP 1
    Map<String, Object> getXSOrderMessageToApp(@Param("orderId") BigDecimal orderId);


    //通过运输订单号查询运输订单类型
    Integer getOrderTypeByOrderNumber(@Param("orderId") BigDecimal orderId);

    //通过车牌号查询该车牌下所有已下发 未接收 的 订单Id （4）
    List<Integer> getOrderIdListByCapacityNumber(String capacityNumber);

    //通过车牌号查询该车牌下所有已接收的订单ID （5）
    List<Integer> getReceiveOrderIdListByCapacityNum(String capacityNumber);

    //通过车牌号查询运输订单号和运输订单ID
    List<Map<String, Object>> getAllRefuseOrderNumberByCapacity(String capacityNumber);

    //通过运输订单Id或运输订单号查询订单类型
    Integer getOrderTypeByOrderId(BigDecimal orderId);

    // 销售中的运输订单
    Map<String, Object> getSaleMap(BigDecimal orderId);
    // 内转钢材的运输订单
    Map<String, Object> getSteelInwardMap(BigDecimal orderId);
    // 采购的运输订单
    Map<String, Object> getPurchaseMap(BigDecimal orderId);
    // 内转的运输订单
    Map<String, Object> getInwardMap(BigDecimal orderId);
    // 判断是走采购，销售还是内转
    List<Map<String, Object>> getResultListByCapacity(String capacityNumber);
    // 通过卸货点名称查询卸货点id
    BigDecimal getUnloadPointId(String unloadPoint);

    // 通过ssoId查询承运商id
    BigDecimal getCarrierIdBySSO(String carrierSsoId);

    List<Map<String, Object>> getOrderMaterialList(BigDecimal orderId);
}